#Region ;**** Directives created by AutoIt3Wrapper_GUI ****
#AutoIt3Wrapper_Icon=Joystick.ico
#AutoIt3Wrapper_Res_Fileversion=1.0.0.0
#AutoIt3Wrapper_Res_ProductVersion=1.0.0
#EndRegion ;**** Directives created by AutoIt3Wrapper_GUI ****

#RequireAdmin
#include <Constants.au3>
#include <Array.au3>

MsgBox(0, "Find Controller HIDs", "This program will simply find all your connected Game Controllers and show the HID for it." & @CRLF & @CRLF & "The HID shown is what goes into the Settings.ini file if you want to make modifications manually or added a brand new controller and want to add it to the already existing Settings.ini file manually." & @CRLF & @CRLF & "Simply copy the HID shown here and add a new Port#= to Settings.ini.")

; Find out which devcon to run depending on OS architecture.
If @OSArch = "X64" Then
	Global $DevCon = @ScriptDir & "\devcon64.exe"
ElseIf @OSArch = "X86" Then
	Global $DevCon = @ScriptDir & "\devcon32.exe"
Else
	MsgBox(16, "Error", "Could not determine if this is an x64 or x86 machine.. ?!")
	Exit
EndIf

; Make sure we really have a devcon command...
If Not FileExists($DevCon) Then
	MsgBox(16, "Error", "Could not find " & $DevCon)
	Exit
EndIf

_FindConnectedHIDS()

; Verify that the controllers are connected
Func _FindConnectedHIDS()
	; Find all HIDs for everything called "game controller".
	Local $CurrentPID = Run(@ComSpec & ' /c ' & Chr(34) & $DevCon & Chr(34) & " status *game controller* | findstr HID\VID", "", @SW_HIDE, $STDERR_CHILD + $STDOUT_CHILD)
	If Not ProcessWaitClose($CurrentPID, 60) Then
		MsgBox(16, "No output", "Did not get any return from " & $DevCon & " status *game controller*", 10)
		Exit
	EndIf
	; Read the output we got.
	$CurrentOutput = StdoutRead($CurrentPID)
	If $CurrentOutput == "" Then
		MsgBox(16, "Error", "Did not find any game controllers when running" & @CRLF & Chr(34) & $DevCon & Chr(34) & " status *game controller*" & @CRLF & @CRLF & "Make sure your controllers are connected.", 10)
		Exit
	EndIf
	; Create a new array from the output from devcon so we know which HIDs actually exists.
	Global $HIDArrayRaw[0]
	Local $HIDArrayRawRaw = StringSplit($CurrentOutput, @CR)
	For $i = 1 To $HIDArrayRawRaw[0]
		Local $HIDCleaned = StringStripWS($HIDArrayRawRaw[$i], 1)
		If $HIDCleaned <> "" Then
			Local $HIDArrayTemp = StringSplit($HIDCleaned, "\")
			Local $HIDCleaned = $HIDArrayTemp[2]
			If $HIDCleaned <> "" Then

				Local $HidNameTemp = StringSplit($HIDCleaned, "&")
				Local $HidNameTemp2 = $HidNameTemp[1] & "&" & $HidNameTemp[2]
				Local $HIDNamed = RegRead("HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\MediaProperties\PrivateProperties\Joystick\OEM\" & $HidNameTemp2, "OEMName")
				If $HIDNamed == "" Then
					$HIDNamed = "Unknown"
				EndIf

				Local $Response = InputBox("Found Controller", $HIDNamed, $HidNameTemp2,"",300,135)
				If $Response = "" Then
					Exit
				EndIf
			EndIf
		EndIf
	Next
	Global $HIDsFound = UBound($HIDArrayRaw)
	Return ("FOUND")
EndFunc   ;==>_FindConnectedHIDS